@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.33';
+$VERSION = '0.34';
 
 #--------------------------------------------------------------------------
 
@@ -111,6 +111,13 @@ sub search {
     return $self->handler("Amazon UK website appears to be unavailable.")
 	    if($@ || !$mech->success() || !$mech->content());
 
+    return $self->_parse($mech);
+}
+
+sub _parse {
+    my $self = shift;
+    my $mech = shift;
+
 	# The Book page
     my $html = $mech->content;
     my $data = {};
@@ -119,14 +126,16 @@ sub search {
 
     my @size                            = $html =~ m!<li><b>\s*Product Dimensions:\s*</b>\s*([\d.]+) x ([\d.]+) x ([\d.]+) (cm)\s*</li>!si;
     @size                               = $html =~ m!<li><b>\s*Product Dimensions:\s*</b>\s*([\d.]+) x ([\d.]+) x ([\d.]+) (inches)\s*</li>!si unless(@size);
-    my $type = pop @size;
-    ($data->{depth},$data->{width},$data->{height}) = sort @size;    
-    if($type eq 'cm') {
-        $data->{$_}  = int($data->{$_} * 10)  for(qw( height width depth ));
-    } elsif($type eq 'inches') {
-        $data->{$_}  = int($data->{$_} / $IN2MM)  for(qw( height width depth ));
+    if(@size) {
+        my $type = pop @size;
+        ($data->{depth},$data->{width},$data->{height}) = sort @size;    
+        if($type eq 'cm') {
+            $data->{$_}  = int($data->{$_} * 10)  for(qw( height width depth ));
+        } elsif($type eq 'inches') {
+            $data->{$_}  = int($data->{$_} / $IN2MM)  for(qw( height width depth ));
+        }
     }
-    
+
     ($data->{binding},$data->{pages})   = $html =~ m!<li><b>(Paperback|Hardcover):</b>\s*([\d.]+)\s*pages</li>!si;
     ($data->{weight})                   = $html =~ m!<li><b>Shipping Weight:</b>\s*([\d.]+)\s*ounces</li>!si;
     ($data->{published})                = $html =~ m!<li><b>Publisher:</b>\s*(.*?)</li>!si;
@@ -135,6 +144,8 @@ sub search {
     ($data->{content})                  = $html =~ m!<meta name="description" content="([^"]+)"!si;
     ($data->{description})              = $html =~ m!From the Back Cover</h3>\s*<div class="productDescriptionWrapper"\s*>\s*<P>(.*?)<div!si;  
 
+    $data->{weight} = int($data->{weight} / $OZ2G)  if($data->{weight});
+
     if($data->{description}) {
         $data->{description} =~ s!<[^>]+>!!g;
         $data->{description} =~ s! +! !g;
@@ -142,32 +153,38 @@ sub search {
 
     # The images
     my ($json) = $html =~ /var colorImages = ([^;]+);/si;
-    my $code = decode_json($json);
-    my @order = grep {$_} $code->{initial}[0]{thumb}, $code->{initial}[0]{landing}, @{$code->{initial}[0]{main}}, $code->{initial}[0]{large};
-    $data->{thumb_link} = $order[0]     if(@order);
-    $data->{image_link} = $order[-1]    if(@order);
+    if($json) {
+        my $code = decode_json($json);
+        my @order = grep {$_} $code->{initial}[0]{thumb}, $code->{initial}[0]{landing}, @{$code->{initial}[0]{main}}, $code->{initial}[0]{large};
+        $data->{thumb_link} = $order[0]     if(@order);
+        $data->{image_link} = $order[-1]    if(@order);
 
 #use Data::Dumper;
 #print STDERR "\n# code=[".Dumper($code)."]\n";
+    }
 
 #    {\"initial\":[{\"large\":\"http://ecx.images-amazon.com/images/I/31cLTIXHKgL.jpg\",\"landing\":[\"http://ecx.images-amazon.com/images/I/31cLTIXHKgL._SY300_.jpg\"],\"thumb\":\"http://ecx.images-amazon.com/images/I/31cLTIXHKgL._SS40_.jpg\",\"main\":[\"http://ecx.images-amazon.com/images/I/31cLTIXHKgL._SX342_.jpg\",\"http://ecx.images-amazon.com/images/I/31cLTIXHKgL._SX385_.jpg\"]}]};
 
-    $data->{content} =~ s/Amazon\.co\.uk.*?://i;
-    $data->{content} =~ s/: Books.*//i;
-	($data->{title},$data->{author}) = ($data->{content} =~ /\s*(.*?)(?:\s+by|,|:)\s+([^:]+)\s*$/);
+    if($data->{content}) {
+        $data->{content} =~ s/Amazon\.co\.uk.*?://i;
+        $data->{content} =~ s/: Books.*//i;
+        ($data->{title},$data->{author}) = ($data->{content} =~ /\s*(.*?)(?:\s+by|,|:)\s+([^:]+)\s*$/);
+    }
 
     ($data->{publisher},$data->{pubdate}) = ($data->{published} =~ /\s*(.*?)(?:;.*?)?\s+\((.*?)\)/) if($data->{published});
     $data->{isbn10}  =~ s/[^\dX]+//g    if($data->{isbn10});
     $data->{isbn13}  =~ s/\D+//g        if($data->{isbn13});
 	$data->{pubdate} =~ s/^.*?\(//      if($data->{pubdate});
 
-
 	return $self->handler("Could not extract data from Amazon UK result page.")
 		unless(defined $data->{isbn13});
 
     # trim top and tail
 	foreach (keys %$data) { next unless(defined $data->{$_});$data->{$_} =~ s/^\s+//;$data->{$_} =~ s/\s+$//; }
 
+#use Data::Dumper;
+#print STDERR "\n# data=[".Dumper($data)."]\n";
+
 	my $bk = {
 		'ean13'		    => $data->{isbn13},
 		'isbn13'		=> $data->{isbn13},
@@ -195,7 +212,7 @@ sub search {
 	return $self->book;
 }
 
-q{currently reading: Nation by Terry Pratchett};
+q{currently reading: 'Torn Apart: The Life of Ian Curtis' by Mick Middles and Lindsay Reade};
 
 __END__
 
@@ -231,7 +248,7 @@ be forthcoming, please feel free to (politely) remind me.
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2004-2013 Barbie for Miss Barbell Productions
+  Copyright (C) 2004-2014 Barbie for Miss Barbell Productions
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
